@@ -21,16 +21,13 @@ CHUNK_SIZE = 512 * 1024  # 512KB
 home = osp.expanduser("~")
 
 
-if hasattr(textwrap, "indent"):
-    indent_func = textwrap.indent
-else:
+# textwrap.indent for Python2
+def indent(text, prefix):
+    def prefixed_lines():
+        for line in text.splitlines(True):
+            yield (prefix + line if line.strip() else line)
 
-    def indent_func(text, prefix):
-        def prefixed_lines():
-            for line in text.splitlines(True):
-                yield (prefix + line if line.strip() else line)
-
-        return "".join(prefixed_lines())
+    return "".join(prefixed_lines())
 
 
 def get_url_from_gdrive_confirmation(contents):
@@ -176,7 +173,7 @@ def download(
         except RuntimeError as e:
             print("Access denied with the following error:")
             error = "\n".join(textwrap.wrap(str(e)))
-            error = indent_func(error, "\t")
+            error = indent(error, "\t")
             print("\n", error, "\n", file=sys.stderr)
             print(
                 "You may still be able to access the file from the browser:",
@@ -186,7 +183,10 @@ def download(
             return
 
     if gdrive_file_id and is_gdrive_download_link:
-        m = re.search('filename="(.*)"', res.headers["Content-Disposition"])
+        content_disposition = six.moves.urllib_parse.unquote(
+            res.headers["Content-Disposition"]
+        )
+        m = re.search(r"filename\*=UTF-8''(.*)", content_disposition)
         filename_from_url = m.groups()[0]
     else:
         filename_from_url = osp.basename(url)
